==> haskell-hls-retrie-plugin-2.1.0.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-retrie-plugin-2.1.0.0-LU3pYTIRU3vJxcQZd73HHh
key:                  hls-retrie-plugin-2.1.0.0-LU3pYTIRU3vJxcQZd73HHh
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  328cb1a975a0a0cdcb7eeb12f8ca34d2
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.1.0.0-LU3pYTIRU3vJxcQZd73HHh
depends:
    aeson-2.1.2.1-4XssoWP8s0tKPHSv4bO4jS base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-FilKm1JQPfHLr5IAgySohi ghc-9.4.8
    ghcide-2.1.0.0-LeHVYn4xxzmCBlpdIjSTbW
    hashable-1.4.4.0-D3m6G7BPJON5VQ2FLdROoK
    hls-plugin-api-2.1.0.0-K4FbFqyLEJN6X72PrrNzeA
    hls-refactor-plugin-2.1.0.0-AWooSfT7HDb2UHWdmNyMZr
    lens-5.3.1-EJGBiJ62DpEHaBgUJVPkQg
    lsp-2.1.0.0-Ftv7hrNHdgW6IKFCFoXoOX
    lsp-types-2.0.1.0-2VjITqMTecEFKvXMh9RptU mtl-2.2.2
    retrie-1.2.3-9tCL5Slb0Tw4IbhKQhJO3a
    safe-exceptions-0.1.7.4-JyBwFDgk1shNJ63ukmgRM stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-3371VA61Be1CojVrkG24uM

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-retrie-plugin-2.1.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-retrie-plugin-2.1.0.0-C5BGgsbnYMu9Oo2jprXnpf
key:                  hls-retrie-plugin-2.1.0.0-C5BGgsbnYMu9Oo2jprXnpf
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  92af6673bbdd102c7a09dc0d628285a5
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.1.0.0-C5BGgsbnYMu9Oo2jprXnpf
depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-3MpJB5o0ESB1pjz4ZT9XVu ghc-9.4.8
    ghcide-2.1.0.0-1KOcaMBafULLEncWomo7Qk
    hashable-1.4.4.0-AmJtI56ndXc1GvGfBNNgwb
    hls-plugin-api-2.1.0.0-KSS8kWBQYXNJC6hz6fAtRu
    hls-refactor-plugin-2.1.0.0-BRdwDP2UsMf67xKfpO9nEQ
    lens-5.3.1-LF4jCoE0w776e2gq32lhyl
    lsp-2.1.0.0-JpAybzOu2bA4LGzZcHHGTh
    lsp-types-2.0.1.0-CpSI1ypjR9r72V9wDhxm76 mtl-2.2.2
    retrie-1.2.3-Leeq90Va8BL4c14xmzWs5j
    safe-exceptions-0.1.7.4-FCgyye4Wo0dEy8n60CbiPd stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
